==> dmntk-model-evaluator-0.0.20.crate: dmntk-model-evaluator-0.0.20/src/errors.rs <==
/*
 * DMNTK - Decision Model and Notation Toolkit
 *
 * DMN model evaluator
 *
 * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

use dmntk_common::{DmntkError, Stringify};
use dmntk_feel::FeelType;

/// Errors related to model evaluation.
#[derive(Error, Debug)]
pub enum ModelEvaluatorError {
  #[error("business knowledge model with name `{0}` was not found")]
  BusinessKnowledgeModelWithNameNotFound(String),
  #[error("decision with name `{0}` was not found")]
  DecisionWithNameNotFound(String),
  #[error("decision service with name `{0}` was not found")]
  DecisionServiceWithNameNotFound(String),
  #[error("multiple rules match in decision table with unique hit policy")]
  MultipleRulesMatchForUniqueHitPolicy,
  #[error("all matching rules must have the same value")]
  AllMatchingRulesMustHaveTheSameValue,
  #[error("the number of output values differ from component names")]
  NumberOfOutputValuesDifferFromComponentNames,
  #[error("aggregators are not allowed for compound outputs")]
  AggregatorsNotAllowedForCompoundOutputs,
  #[error("input data with specified identifier `{0}` was not found in definitions")]
  InputDataWithSpecifiedIdNotFound(String),
  #[error("input data with identifier `{0}` has no type reference definition")]
  InputDataWithoutTypeReference(String),
  #[error("empty FEEL name")]
  EmptyFeelName,
  #[error("empty identifier")]
  EmptyIdentifier,
  #[error("empty decision logic in decision")]
  EmptyLiteralExpression,
  #[error("empty literal expression")]
  EmptyDecisionLogic,
  #[error("empty encapsulated logic in business knowledge model")]
  EmptyEncapsulatedLogic,
  #[error("invalid item definition type for `{0}`")]
  InvalidItemDefinitionType(String),
  #[error("unsupported FEEL type: {0}")]
  UnsupportedFeelType(String),
  #[error("empty FEEL type reference")]
  EmptyFeelTypeReference,
  #[error("empty FEEL type")]
  EmptyFeelType,
}

impl From<ModelEvaluatorError> for DmntkError {
  fn from(e: ModelEvaluatorError) -> Self {
    DmntkError::new("ModelEvaluatorError", &e.to_string())
  }
}

pub fn err_business_knowledge_model_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::BusinessKnowledgeModelWithNameNotFound(name.to_string()).into()
}

pub fn err_decision_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::DecisionWithNameNotFound(name.to_string()).into()
}

pub fn err_decision_service_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::DecisionServiceWithNameNotFound(name.to_string()).into()
}

pub fn err_multiple_rules_match_in_unique_hit_policy() -> DmntkError {
  ModelEvaluatorError::MultipleRulesMatchForUniqueHitPolicy.into()
}

pub fn err_all_matching_rules_must_have_the_same_value() -> DmntkError {
  ModelEvaluatorError::AllMatchingRulesMustHaveTheSameValue.into()
}

pub fn err_number_of_output_values_differ_from_component_names() -> DmntkError {
  ModelEvaluatorError::NumberOfOutputValuesDifferFromComponentNames.into()
}

pub fn err_aggregators_not_allowed_for_compound_outputs() -> DmntkError {
  ModelEvaluatorError::AggregatorsNotAllowedForCompoundOutputs.into()
}

pub fn err_input_data_with_specified_id_not_found(s: &str) -> DmntkError {
  ModelEvaluatorError::InputDataWithSpecifiedIdNotFound(s.to_string()).into()
}

pub fn err_input_data_without_type_reference(s: &str) -> DmntkError {
  ModelEvaluatorError::InputDataWithoutTypeReference(s.to_string()).into()
}

pub fn err_empty_feel_name() -> DmntkError {
  ModelEvaluatorError::EmptyFeelName.into()
}

pub fn err_empty_identifier() -> DmntkError {
  ModelEvaluatorError::EmptyIdentifier.into()
}

pub fn err_empty_literal_expression() -> DmntkError {
  ModelEvaluatorError::EmptyLiteralExpression.into()
}

pub fn err_empty_decision_logic() -> DmntkError {
  ModelEvaluatorError::EmptyDecisionLogic.into()
}

pub fn err_empty_encapsulated_logic() -> DmntkError {
  ModelEvaluatorError::EmptyEncapsulatedLogic.into()
}

pub fn err_invalid_item_definition_type(s: &str) -> DmntkError {
  ModelEvaluatorError::InvalidItemDefinitionType(s.to_string()).into()
}

pub fn err_unsupported_feel_type(feel_type: FeelType) -> DmntkError {
  ModelEvaluatorError::UnsupportedFeelType(feel_type.stringify()).into()
}

pub fn err_empty_feel_type_reference() -> DmntkError {
  ModelEvaluatorError::EmptyFeelTypeReference.into()
}

pub fn err_empty_feel_type() -> DmntkError {
  ModelEvaluatorError::EmptyFeelType.into()
}

==> dmntk-model-evaluator-0.0.35.crate: dmntk-model-evaluator-0.0.35/src/errors.rs <==
/*
 * DMNTK - Decision Model and Notation Toolkit
 *
 * DMN model evaluator
 *
 * Copyright 2018-2021 Dariusz Depta Engos Software <dariusz.depta@engos.software>
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

use dmntk_common::DmntkError;
use dmntk_feel::FeelType;

/// Errors related to model evaluation.
#[derive(Error, Debug)]
pub enum ModelEvaluatorError {
  #[error("business knowledge model with name `{0}` was not found")]
  BusinessKnowledgeModelWithNameNotFound(String),
  #[error("business knowledge model with reference `{0}` was not found")]
  BusinessKnowledgeModelWithReferenceNotFound(String),
  #[error("decision with name `{0}` was not found")]
  DecisionWithNameNotFound(String),
  #[error("decision service with name `{0}` was not found")]
  DecisionServiceWithNameNotFound(String),
  #[error("input data with identifier `{0}` has no type reference definition")]
  InputDataWithoutTypeReference(String),
  #[error("empty FEEL name")]
  EmptyFeelName,
  #[error("empty identifier")]
  EmptyIdentifier,
  #[error("empty decision logic in decision")]
  EmptyLiteralExpression,
  #[error("empty literal expression")]
  EmptyDecisionLogic,
  #[error("empty encapsulated logic in business knowledge model")]
  EmptyEncapsulatedLogic,
  #[error("invalid item definition type for `{0}`")]
  InvalidItemDefinitionType(String),
  #[error("unsupported FEEL type: {0}")]
  UnsupportedFeelType(String),
  #[error("empty FEEL type")]
  EmptyFeelType,
  #[error("empty reference")]
  EmptyReference,
  #[error("empty function definition body")]
  EmptyFunctionBody,
  #[error("empty value expression")]
  EmptyValueExpression,
}

impl From<ModelEvaluatorError> for DmntkError {
  fn from(e: ModelEvaluatorError) -> Self {
    DmntkError::new("ModelEvaluatorError", &e.to_string())
  }
}

pub fn err_business_knowledge_model_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::BusinessKnowledgeModelWithNameNotFound(name.to_string()).into()
}

pub fn err_business_knowledge_model_with_reference_not_found(reference: &str) -> DmntkError {
  ModelEvaluatorError::BusinessKnowledgeModelWithReferenceNotFound(reference.to_string()).into()
}

pub fn err_decision_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::DecisionWithNameNotFound(name.to_string()).into()
}

pub fn err_decision_service_with_name_not_found(name: &str) -> DmntkError {
  ModelEvaluatorError::DecisionServiceWithNameNotFound(name.to_string()).into()
}

pub fn err_input_data_without_type_reference(s: &str) -> DmntkError {
  ModelEvaluatorError::InputDataWithoutTypeReference(s.to_string()).into()
}

pub fn err_empty_feel_name() -> DmntkError {
  ModelEvaluatorError::EmptyFeelName.into()
}

pub fn err_empty_identifier() -> DmntkError {
  ModelEvaluatorError::EmptyIdentifier.into()
}

pub fn err_empty_literal_expression() -> DmntkError {
  ModelEvaluatorError::EmptyLiteralExpression.into()
}

pub fn err_empty_decision_logic() -> DmntkError {
  ModelEvaluatorError::EmptyDecisionLogic.into()
}

pub fn err_empty_encapsulated_logic() -> DmntkError {
  ModelEvaluatorError::EmptyEncapsulatedLogic.into()
}

pub fn err_invalid_item_definition_type(s: &str) -> DmntkError {
  ModelEvaluatorError::InvalidItemDefinitionType(s.to_string()).into()
}

pub fn err_unsupported_feel_type(feel_type: FeelType) -> DmntkError {
  ModelEvaluatorError::UnsupportedFeelType(feel_type.to_string()).into()
}

pub fn err_empty_feel_type() -> DmntkError {
  ModelEvaluatorError::EmptyFeelType.into()
}

pub fn err_empty_reference() -> DmntkError {
  ModelEvaluatorError::EmptyReference.into()
}

pub fn err_empty_function_body() -> DmntkError {
  ModelEvaluatorError::EmptyFunctionBody.into()
}

pub fn err_empty_value_expression() -> DmntkError {
  ModelEvaluatorError::EmptyValueExpression.into()
}
